@@ -14,49 +14,37 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file init_delegation.c
+ * @file gssapi/source/library/init_delegation.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: accept_delegation.c,v $
- * $Revision: 1.38.42.1 $
- * $Date: 2012/05/07 18:38:53 $
  */
-#endif
-
-static char *rcsid = "$Id: accept_delegation.c,v 1.38.42.1 2012/05/07 18:38:53 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
 
 /* Only build if we have the extended GSSAPI */
 #ifdef _HAVE_GSI_EXTENDED_GSSAPI
-
 /**
- * @name Accept Delegation
- */
-/*@{*/
-/**
- * Accept a delegated credential.
- *
+ * @brief Accept a delegated credential
+ * @ingroup globus_gsi_gssapi_extensions_delegation
+ * @details
  * This functions drives the accepting side of the credential
  * delegation process. It is expected to be called in tandem with the
  * gss_init_delegation function.
  *
  * @param minor_status
- *        The minor status returned by this function. This paramter
+ *        The minor status returned by this function. This parameter
  *        will be 0 upon success.
  * @param context_handle
  *        The security context over which the credential is
  *        delegated. 
  * @param extension_oids
- *        A set of extension oids corresponding to buffers in the
- *        extension_buffers paramter below. May be
+ *        A set of extension OIDs corresponding to buffers in the
+ *        extension_buffers parameter below. May be
  *        GSS_C_NO_BUFFER_SET. Currently not used.
  * @param extension_buffers
- *        A set of extension buffers corresponding to oids in the
- *        extension_oids paramter above. May be
+ *        A set of extension buffers corresponding to OIDs in the
+ *        extension_oids parameter above. May be
  *        GSS_C_NO_BUFFER_SET. Currently not used. 
  * @param input_token
  *        The token that was produced by a prior call to
@@ -67,7 +55,7 @@ static char *rcsid = "$Id: accept_delegation.c,v 1.38.42.1 2012/05/07 18:38:53 b
  *        results in tokens that aren't wrapped.
  * @param time_req
  *        The requested period of validity (seconds) of the delegated
- *        credential. Currently a noop.
+ *        credential. Currently a NO-OP.
  * @param time_rec
  *        This parameter will contain the received period of validity
  *        of the delegated credential upon success. May be NULL.
@@ -80,11 +68,10 @@ static char *rcsid = "$Id: accept_delegation.c,v 1.38.42.1 2012/05/07 18:38:53 b
  * @param output_token
  *        A token that should be passed to gss_init_delegation if the
  *        return value is GSS_S_CONTINUE_NEEDED.
- * @return
- *        GSS_S_COMPLETE upon successful completion
- *        GSS_S_CONTINUE_NEEDED if the function needs to be called
- *                              again.
- *        GSS_S_FAILURE upon failure
+ * @retval GSS_S_COMPLETE Successful completion
+ * @retval GSS_S_CONTINUE_NEEDED
+ *        The function needs to be called again.
+ * @retval GSS_S_FAILURE Failure
  */
 OM_uint32
 GSS_CALLCONV gss_accept_delegation(
@@ -433,6 +420,4 @@ GSS_CALLCONV gss_accept_delegation(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
-
 #endif /* _HAVE_GSI_EXTENDED_GSSAPI */
