@@ -14,31 +14,20 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file accept_sec_context.h
- * Globus GSI GSS-API gss_accept_sec_context
+ * @file gssapi/source/library/accept_sec_context.c
+ * @brief Globus GSI GSS-API gss_accept_sec_context
  * @author Sam Meder, Sam Lang
- *
- * $RCSfile: accept_sec_context.c,v $
- * $Revision: 1.36.2.1 $
- * $Date: 2013/10/10 15:22:00 $
  */
-#endif
-
-static char * rcsid = "$Id: accept_sec_context.c,v 1.36.2.1 2013/10/10 15:22:00 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
 #include <string.h>
 
 /**
- * @name GSS Accept Security Context
+ * @brief GSS Accept Security Context
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
- * 
+ * @details
  * @param minor_status
  * @param context_handle_P
  * @param acceptor_cred_handle
@@ -281,7 +270,7 @@ GSS_CALLCONV gss_accept_sec_context(
 #           endif
             /* 
              * IF we are talking to a real SSL client,
-             * we dont want to do delegation, so we are done
+             * we don't want to do delegation, so we are done
              */
             if (context->req_flags & GSS_C_GLOBUS_SSL_COMPATIBLE)
             {
@@ -291,7 +280,7 @@ GSS_CALLCONV gss_accept_sec_context(
         
             /* 
              * To keep the gss exchange going, if we received
-             * the last token but dont have a token to send
+             * the last token but don't have a token to send
              * we need to send a null So peek at what we might send
              */
             if (BIO_pending(context->gss_wbio) == 0)
@@ -635,4 +624,3 @@ GSS_CALLCONV gss_accept_sec_context(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
