@@ -14,19 +14,11 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file compare_name.c
- * Globus GSI GSS-API gss_compare_name
+ * @file gssapi/source/library/compare_name.c
+ * @brief Globus GSI GSSAPI gss_compare_name
  * @author Sam Meder, Sam Lang
- *
- * $RCSfile: compare_name.c,v $
- * $Revision: 1.30.42.1 $
- * $Date: 2012/02/13 14:44:54 $
  */
-#endif
-
-static char *rcsid = "$Id: compare_name.c,v 1.30.42.1 2012/02/13 14:44:54 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -174,13 +166,11 @@ gss_l_get_oid_type(
     gss_OID                             oid);
 
 /**
- * @name Compare Name
+ * @brief Compare Name
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
+ * @details
  * Compare two names. GSSAPI names in this implementation
- * are pointers to x509 names. 
+ * are pointers to X.509 names. 
  *
  * @param minor_status
  *        currently is always set to GLOBUS_SUCCESS
@@ -387,7 +377,6 @@ GSS_CALLCONV gss_compare_name(
 
 } 
 /* gss_compare_name */
-/* @} */
 
 static
 OM_uint32
