@@ -14,18 +14,10 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file get_mic.c
+ * @file gssapi/source/library/get_mic.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: get_mic.c,v $
- * $Revision: 1.9.28.1 $
- * $Date: 2013/02/22 16:11:24 $
  */
-#endif
-
-static char * rcsid = "$Id: get_mic.c,v 1.9.28.1 2013/02/22 16:11:24 bester Exp $";
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 
@@ -45,12 +37,10 @@ static unsigned char ssl3_pad_1[48]={
 #include "gssapi.h"
 #include "globus_i_gsi_gss_utils.h"
 #include "gssapi_openssl.h"
+
 /**
- * @name Get MIC
+ * @brief Get MIC
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
  * Calculates a cryptographic MIC (message integrity check)
  * over an application message, and returns that MIC in the token.
  * The token and message can then be passed to the peer application
@@ -225,7 +215,7 @@ GSS_CALLCONV gss_get_mic(
         
         GLOBUS_I_GSI_GSSAPI_DEBUG_FPRINTF(
             2, (globus_i_gsi_gssapi_debug_fstream,
-                "get_mic: len=%u mic:", message_token->length));
+                "get_mic: len=%zd mic:", message_token->length));
         p = message_token->value;
         for (index = 0;  index < message_token->length; index++)
         {
@@ -243,15 +233,12 @@ GSS_CALLCONV gss_get_mic(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Sign
+ * @brief Sign
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
- * Deprecated.  Does the same thing as gss_get_mic for V1 compatability.
+ * @details
+ * Deprecated.  Does the same thing as gss_get_mic for V1 compatibility.
  *
  * @param minor_status
  * @param context_handle
@@ -284,4 +271,3 @@ GSS_CALLCONV gss_sign(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
