@@ -14,18 +14,11 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file globus_i_gsi_gss_utils.c
+ * @file gssapi/source/library/globus_i_gsi_gss_utils.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: globus_i_gsi_gss_utils.c,v $
- * $Revision: 1.66 $
- * $Date: 2011/11/02 13:47:22 $
  */
 
-static char *rcsid = "$Id: globus_i_gsi_gss_utils.c,v 1.66 2011/11/02 13:47:22 bester Exp $";
-
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
 #include "globus_gsi_credential.h"
@@ -47,9 +40,9 @@ static char *rcsid = "$Id: globus_i_gsi_gss_utils.c,v 1.66 2011/11/02 13:47:22 b
 extern int                              globus_i_gsi_gssapi_debug_level;
 extern FILE *                           globus_i_gsi_gssapi_debug_fstream;
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @anchor globus_i_gsi_gss_utils
- * @mainpage Globus GSI GSS-API
+ * @defgroup globus_i_gsi_gss_utils Globus GSSAPI Internals
  *
  * The globus_i_gsi_gss_utils code is used by the other 
  * gss api code to perform internal functions such as
@@ -57,11 +50,9 @@ extern FILE *                           globus_i_gsi_gssapi_debug_fstream;
  */
 
 /**
- * @name Copy GSS API Name
+ * @brief Copy GSS API Name
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
+ * @details
  * Copy a gss_name_t structure, including the group information
  * and the name's OID.
  *
@@ -73,9 +64,8 @@ extern FILE *                           globus_i_gsi_gssapi_debug_fstream;
  *        Target name.
  * @param input
  *        Source name.
- * @return
- *        GSS_S_COMPLETE - successful copy
- *        GSS_F_FAILURE - failed to copy
+ * @retval GSS_S_COMPLETE Success
+ * @retval GSS_F_FAILURE Failed to copy
  */
 OM_uint32 
 globus_i_gsi_gss_copy_name_to_name(
@@ -207,15 +197,11 @@ globus_i_gsi_gss_copy_name_to_name(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;    
     return major_status;
 }
-/* @} */
 
 /**
- * @name Init Security Context
+ * @brief Initialize a Security Context
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
- * Initialize a security context structure.
+ * @details
  *
  * Called by the GSSAPI functions @ref gss_init_sec_context 
  * and @ref gss_accept_sec_context to 
@@ -702,15 +688,11 @@ globus_i_gsi_gss_create_and_fill_context(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Put Token
- * @group globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
- * 
+ * @brief Put Token
+ * @ingroup globus_i_gsi_gss_utils
+ * @details
  * Called by init_sec_context and accept_sec_context.
  * An input token is placed in the SSL read BIO
  * 
@@ -799,14 +781,11 @@ globus_i_gsi_gss_put_token(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Get Token
- * @group globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
+ * @brief Get Token
+ * @ingroup globus_i_gsi_gss_utils
+ * @details
  * Get the token from the context handle
  *
  * @param minor_status
@@ -904,14 +883,11 @@ exit:
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Handshake
+ * @brief Handshake
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
+ * @details
  * Do the SSL handshake
  *
  * Called by init_sec_context and accept_sec_context.
@@ -1086,16 +1062,11 @@ globus_i_gsi_gss_handshake(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Retrieve Peer
+ * @brief Retrieve Peer
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
- * Retrieve Peer
- *
+ * @details
  * Called after the handshake has completed sucessfully,
  * and gets the subject name, so it can be returned to the
  * call of the GSSAPI init_sec_context or accept_sec_context. 
@@ -1225,15 +1196,10 @@ globus_i_gsi_gss_retrieve_peer(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Create Anonymous Cred
+ * @brief Create Anonymous Cred
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
- * Create Anonymous Cred
  *
  * @param minor_status
  * @param output_cred_handle
@@ -1461,16 +1427,11 @@ globus_i_gsi_gss_cred_read(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Create Cred
+ * @brief Create Cred
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
- * Create Cred
- * 
+ * @details
  * Called by acquire_cred and accept_sec_context for a delegate.
  * Setup the credential including the SSL_CTX
  *
@@ -1642,7 +1603,6 @@ globus_i_gsi_gss_create_cred(
     GLOBUS_I_GSI_GSSAPI_DEBUG_ENTER;
     return major_status;
 }
-/* @} */
 
 
 #if LINK_WITH_INTERNAL_OPENSSL_API
@@ -1838,24 +1798,30 @@ globus_i_gsi_gss_SSL_read_bio(
     BIO_read(bp, (char *) int_buffer, 4); 
     N2L(int_buffer, length);
 
-    if (BIO_pending(bp) < length)
+    if (length > 0)
     {
-        major_status = GSS_S_NO_CONTEXT;
-        GLOBUS_GSI_GSSAPI_ERROR_RESULT(
-            minor_status,
-            GLOBUS_GSI_GSSAPI_ERROR_IMPEXP_BAD_LEN,
-            (_GGSL("Invalid BIO - not enough data to read an int")));
-        goto exit;
-    }
+        if (BIO_pending(bp) < length)
+        {
+            major_status = GSS_S_NO_CONTEXT;
+            GLOBUS_GSI_GSSAPI_ERROR_RESULT(
+                minor_status,
+                GLOBUS_GSI_GSSAPI_ERROR_IMPEXP_BAD_LEN,
+                (_GGSL("Invalid BIO - not enough data to read an int")));
+            goto exit;
+        }
 
-    ssl_handle->s3->tmp.key_block = (unsigned char *) OPENSSL_malloc(length);
-    if (ssl_handle->s3->tmp.key_block == NULL)
+        ssl_handle->s3->tmp.key_block = (unsigned char *) OPENSSL_malloc(length);
+        if (ssl_handle->s3->tmp.key_block == NULL)
+        {
+            GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
+            major_status = GSS_S_FAILURE;
+            goto exit;
+        }
+    }
+    else
     {
-        GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
-        major_status = GSS_S_FAILURE;
-        goto exit;
+        ssl_handle->s3->tmp.key_block = NULL;
     }
-                
     ssl_handle->s3->tmp.key_block_length = length;
 
     GLOBUS_I_GSI_GSSAPI_DEBUG_FPRINTF(
@@ -2039,15 +2005,12 @@ globus_i_gsi_gss_SSL_read_bio(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 #endif /* LINK_WITH_INTERNAL_OPENSSL_API */
 
 /**
- * @name Init SSL Context
+ * @brief Init SSL Context
  * @ingroup globus_i_gsi_gssapi
- */
-/* @{ */
-/**
+ * @details
  * Initialize the SSL Context for use in the SSL authentication mechanism.
  * The ssl context held by the cred handle is used to generate SSL objects
  * for the SSL handshake.  Initializing the SSL context consists of
@@ -2304,6 +2267,51 @@ globus_i_gsi_gssapi_init_ssl_context(
             }
         }
     }
+    else
+    {
+        char *                          extra_pem;
+
+        extra_pem = getenv("GLOBUS_GFS_EXTRA_CA_CERTS");
+        if(extra_pem)
+        {
+            X509 *                      extra_x509 = NULL;
+            BIO *                       B_mem;
+
+            B_mem = BIO_new(BIO_s_mem());
+            BIO_puts(B_mem, extra_pem);
+            extra_x509 = PEM_read_bio_X509(B_mem, NULL, 0, NULL);
+            BIO_free(B_mem);
+
+            if(extra_x509)
+            {
+                if(!X509_STORE_add_cert(
+                    SSL_CTX_get_cert_store(cred_handle->ssl_context),
+                    extra_x509))
+                {
+                    /* need to free to reduce ref count */
+                    X509_free(extra_x509);
+                    if ((ERR_GET_REASON(ERR_peek_error()) ==
+                         X509_R_CERT_ALREADY_IN_HASH_TABLE))
+                    {
+                        ERR_clear_error();
+                    }
+                    else
+                    {
+                        GLOBUS_GSI_GSSAPI_OPENSSL_ERROR_RESULT(
+                            minor_status,
+                            GLOBUS_GSI_GSSAPI_ERROR_WITH_OPENSSL,
+                            (_GGSL("Couldn't add certificate to the SSL context's "
+                             "certificate store.")));
+                        major_status = GSS_S_FAILURE;
+                        goto exit;
+                    }
+                }
+            }
+            /* need to free to reduce ref count */
+            X509_free(extra_x509);
+        }
+    }
+
 
  exit:
 
@@ -2330,7 +2338,6 @@ globus_i_gsi_gssapi_init_ssl_context(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 OM_uint32
 globus_i_gsi_gss_get_context_goodtill(
@@ -2390,14 +2397,11 @@ globus_i_gsi_gss_get_context_goodtill(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 /**
- * @name Verify Extensions Callback
+ * @brief Verify Extensions Callback
  * @ingroup globus_i_gsi_gss_utils
- */
-/* @{ */
-/**
+ * @details
  * Verify Extensions Callback 
  *
  * @param callback_data
@@ -2456,7 +2460,6 @@ int globus_i_gsi_gss_verify_extensions_callback(
     GLOBUS_I_GSI_GSSAPI_INTERNAL_DEBUG_EXIT;
     return return_val;
 }
-/* @} */
 
 OM_uint32
 globus_i_gsi_gssapi_get_hostname(
