@@ -14,29 +14,21 @@
  * limitations under the License.
  */
 
-#ifndef _GSSAPI_OPENSSL_H
-#define _GSSAPI_OPENSSL_H
+#ifndef GSSAPI_OPENSSL_H
+#define GSSAPI_OPENSSL_H
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file gssapi_openssl.h
+ * @brief GSS API OpenSSL
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: gssapi_openssl.h,v $
- * $Revision: 1.12.28.1 $
- * $Date: 2012/02/13 14:44:54 $
  */
-#endif
 
-#if defined(WIN32)
-#define _WINSOCKAPI_  //rcg 9/23/03
-#   include "windows.h"
-#endif
+#include "globus_config.h"
+#include "globus_common.h"
 
 #include "gssapi.h"
 #include "globus_gsi_gss_constants.h"
 
-#include "globus_common.h"
 #include "globus_gsi_callback.h"
 #include "globus_gsi_proxy.h"
 #include "globus_gsi_credential.h"
@@ -187,4 +179,4 @@ globus_thread_once_t                    once_control;
 void
 globus_l_gsi_gssapi_activate_once(void);
 
-#endif /* _GSSAPI_OPENSSL_H */
+#endif /* GSSAPI_OPENSSL_H */
