@@ -14,50 +14,39 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file import_cred.c
+ * @file gssapi/source/library/import_cred.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: import_cred.c,v $
- * $Revision: 1.21.50.2 $
- * $Date: 2012/03/09 17:59:43 $
  */
-#endif
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
+
 #include <string.h>
 
 /* Only build if we have the extended GSSAPI */
 #ifdef  _HAVE_GSI_EXTENDED_GSSAPI
 
-static char *rcsid = "$Id: import_cred.c,v 1.21.50.2 2012/03/09 17:59:43 bester Exp $";
-
 /**
- * @name Import Cred
+ * @brief Import a credential
  * @ingroup globus_gsi_gssapi_extensions
- */
-/* @{ */
-/**
- * Import a credential that was exported by gss_export_cred().
- *
+ * @details
  * This function will import credentials exported by
  * gss_export_cred(). It is intended to allow a multiple use
  * application to checkpoint delegated credentials.  
  *
  * @param minor_status
- *        The minor status returned by this function. This paramter
+ *        The minor status returned by this function. This parameter
  *        will be 0 upon success.
  * @param output_cred_handle
- *        Upon success, this paramter will contain the imported
+ *        Upon success, this parameter will contain the imported
  *        credential. When no longer needed this credential should be
  *        freed using gss_release_cred().
  * @param desired_mech
- *        This paramter may be used to specify the desired security
+ *        This parameter may be used to specify the desired security
  *        mechanism. May be GSS_C_NO_OID.
  * @param option_req
- *        This paramater indicates which option_req value was used to
+ *        This parameter indicates which option_req value was used to
  *        produce the import_buffer.
  * @param import_buffer
  *        A buffer produced by gss_export_credential().
@@ -67,12 +56,10 @@ static char *rcsid = "$Id: import_cred.c,v 1.21.50.2 2012/03/09 17:59:43 bester
  * @param time_rec
  *        This parameter will contain the received period of validity
  *        of the imported credential upon success. May be NULL.
- * @return
- *        GSS_S_COMPLETE         upon successful completion
- *        GSS_S_BAD_MECH         if the requested security mechanism
- *                               is unavailable
- *        GSS_S_DEFECTIVE_TOKEN  if the import_buffer is defective
- *        GSS_S_FAILURE          upon general failure
+ * @retval GSS_S_COMPLETE Success
+ * @retval GSS_S_BAD_MECH Requested security mechanism is unavailable
+ * @retval GSS_S_DEFECTIVE_TOKEN import_buffer is defective
+ * @retval GSS_S_FAILURE General failure
  */
 OM_uint32 
 GSS_CALLCONV gss_import_cred(
@@ -268,6 +255,5 @@ GSS_CALLCONV gss_import_cred(
     }
     return major_status;
 }
-/* @} */
 
 #endif /* _HAVE_GSI_EXTENDED_GSSAPI */
