@@ -14,18 +14,10 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file import_name.c
+ * @file gssapi/source/library/import_name.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: import_name.c,v $
- * $Revision: 1.21 $
- * $Date: 2011/04/19 14:01:52 $
  */
-#endif
-
-static char *rcsid = "$Id: import_name.c,v 1.21 2011/04/19 14:01:52 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
