@@ -14,16 +14,10 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file init_delegation.c
+ * @file gssapi/source/library/init_delegation.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: init_delegation.c,v $
- * $Revision: 1.42 $
- * $Date: 2008/09/10 21:01:06 $
  */
-#endif
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -33,21 +27,16 @@
 /* Only build if we have the extended GSSAPI */
 #ifdef _HAVE_GSI_EXTENDED_GSSAPI
 
-static char *rcsid = "$Id: init_delegation.c,v 1.42 2008/09/10 21:01:06 bester Exp $";
-
 /**
- * @name Init Delegation
- */
-/*@{*/
-/**
- * Initiate the delegation of a credential.
- *
+ * @brief Initiate Delegation
+ * @ingroup globus_gsi_gssapi_extensions_delegation
+ * @details
  * This functions drives the initiating side of the credential
  * delegation process. It is expected to be called in tandem with the
  * gss_accept_delegation function.
  *
  * @param minor_status
- *        The minor status returned by this function. This paramter
+ *        The minor status returned by this function. This parameter
  *        will be 0 upon success.
  * @param context_handle
  *        The security context over which the credential is
@@ -60,13 +49,13 @@ static char *rcsid = "$Id: init_delegation.c,v 1.42 2008/09/10 21:01:06 bester E
  *        The desired security mechanism. Currently not used. May be
  *        GSS_C_NO_OID. 
  * @param extension_oids
- *        A set of extension oids corresponding to buffers in the
+ *        A set of extension OIDs corresponding to buffers in the
  *        extension_buffers parameter below. The extensions specified
  *        will be added to the delegated credential. May be
  *        GSS_C_NO_BUFFER_SET. 
  * @param extension_buffers
- *        A set of extension buffers corresponding to oids in the
- *        extension_oids paramter above. May be
+ *        A set of extension buffers corresponding to OIDs in the
+ *        extension_oids parameter above. May be
  *        GSS_C_NO_BUFFER_SET.
  * @param input_token
  *        The token that was produced by a prior call to
@@ -88,11 +77,9 @@ static char *rcsid = "$Id: init_delegation.c,v 1.42 2008/09/10 21:01:06 bester E
  * @param output_token
  *        A token that should be passed to gss_accept_delegation if the
  *        return value is GSS_S_CONTINUE_NEEDED.
- * @return
- *        GSS_S_COMPLETE upon successful completion
- *        GSS_S_CONTINUE_NEEDED if the function needs to be called
- *                              again.
- *        GSS_S_FAILURE upon failure
+ * @retval GSS_S_COMPLETE Success
+ * @retval GSS_S_CONTINUE_NEEDED This function needs to be called again.
+ * @retval GSS_S_FAILURE upon failure
  */
 OM_uint32
 GSS_CALLCONV gss_init_delegation(
@@ -492,6 +479,5 @@ GSS_CALLCONV gss_init_delegation(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 #endif /* _HAVE_GSI_EXTENDED_GSSAPI */
