@@ -14,18 +14,10 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file init_sec_context.c
+ * @file gssapi/source/library/init_sec_context.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: init_sec_context.c,v $
- * $Revision: 1.41 $
- * $Date: 2011/11/02 13:47:22 $
  */
-#endif
-
-static char *rcsid = "$Id: init_sec_context.c,v 1.41 2011/11/02 13:47:22 bester Exp $";
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -35,9 +27,9 @@ static char *rcsid = "$Id: init_sec_context.c,v 1.41 2011/11/02 13:47:22 bester
 #include "globus_gsi_cert_utils.h"
 
 /**
- * @name Init Sec Context
+ * @brief Init Sec Context
+ * @ingroup globus_gsi_gssapi
  */
-/*@{*/
 OM_uint32 
 GSS_CALLCONV gss_init_sec_context(
     OM_uint32 *                         minor_status,
@@ -329,7 +321,7 @@ GSS_CALLCONV gss_init_sec_context(
 
         /* 
          * IF we are talking to a real SSL server,
-         * we dont want to do delegation, so we are done
+         * we don't want to do delegation, so we are done
          */
 
         if (context->req_flags & GSS_C_GLOBUS_SSL_COMPATIBLE)
@@ -339,7 +331,7 @@ GSS_CALLCONV gss_init_sec_context(
         }
             
         /*
-         * If we have completed the handshake, but dont
+         * If we have completed the handshake, but don't
          * have any more data to send, we can send the flag
          * now. i.e. fall through without break,
          * Otherwise, we will wait for the null byte
@@ -523,4 +515,3 @@ GSS_CALLCONV gss_init_sec_context(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
