@@ -14,16 +14,10 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file inquire_sec_context_by_oid.c
+ * @file gssapi/source/library/inquire_sec_context_by_oid.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: inquire_sec_context_by_oid.c,v $
- * $Revision: 1.29 $
- * $Date: 2010/03/16 18:19:20 $
  */
-#endif
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
@@ -32,14 +26,14 @@
 /* Only build if we have the extended GSSAPI */
 #ifdef _HAVE_GSI_EXTENDED_GSSAPI
 
-static char *rcsid = "$Id: inquire_sec_context_by_oid.c,v 1.29 2010/03/16 18:19:20 bester Exp $";
+static char *rcsid = "$Id$";
 
 extern const gss_OID_desc * const gss_ext_x509_cert_chain_oid;
 
 /**
- * @name Inquire Sec Context by OID
+ * @brief Inquire Sec Context by OID
+ * @ingroup globus_gsi_gssapi_extensions
  */
-/* @{ */
 OM_uint32
 GSS_CALLCONV gss_inquire_sec_context_by_oid(
     OM_uint32 *                         minor_status,
@@ -251,11 +245,13 @@ GSS_CALLCONV gss_inquire_sec_context_by_oid(
     {
         for(chain_index = 0; chain_index < cert_count; chain_index++)
         {
+            int certlen;
             cert = sk_X509_value(cert_chain, chain_index);
 
-            data_set_buffer.length = i2d_X509(cert, NULL);
+            certlen = i2d_X509(cert, NULL);
+            data_set_buffer.length = certlen;
 
-            if(data_set_buffer.length < 0)
+            if (certlen < 0)
             {
                 GLOBUS_GSI_GSSAPI_OPENSSL_ERROR_RESULT(
                     minor_status,
@@ -324,6 +320,5 @@ exit:
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
 
 #endif /* _HAVE_GSI_EXTENDED_GSSAPI */
