@@ -14,22 +14,14 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file gss_verify_mic
+ * @file gssapi/source/library/verify_mic.c
  * @author Sam Lang, Sam Meder
- * 
- * $RCSfile: verify_mic.c,v $
- * $Revision: 1.14.28.2 $
- * $Date: 2013/10/10 17:29:10 $
  */
-#endif
-
-static char *rcsid = "$Id: verify_mic.c,v 1.14.28.2 2013/10/10 17:29:10 bester Exp $";
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 
-/* borrowed from OpenSSL's s3_enc.c
+/* borrowed from OpenSSLs s3_enc.c
  */
 static unsigned char ssl3_pad_1[48]={
 	0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
@@ -49,11 +41,9 @@ static unsigned char ssl3_pad_1[48]={
 #include <time.h>
 
 /**
- * @name Verify MIC
+ * @brief Verify MIC
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
+ * @details
  * Check a MIC of the data
  *
  * @param minor_status
@@ -165,7 +155,7 @@ GSS_CALLCONV gss_verify_mic(
 
         GLOBUS_I_GSI_GSSAPI_DEBUG_FPRINTF(
             2, (globus_i_gsi_gssapi_debug_fstream,
-                "verify_mic: len=%u mic:",
+                "verify_mic: len=%zd mic:",
                 token_buffer->length));
         debug_token_value = token_buffer->value;
 
@@ -265,7 +255,7 @@ GSS_CALLCONV gss_verify_mic(
     }
 
     /*
-     * Now test for consistance with the MIC
+     * Now test for consistency with the MIC
      */    
     token_value = token_buffer->value;
     
@@ -320,15 +310,12 @@ exit:
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 } 
-/* @} */
 
 /**
- * @name Verify
+ * @brief Verify
  * @ingroup globus_gsi_gssapi
- */
-/* @{ */
-/**
- * Obsolete variant of gss_verify for V1 compatability 
+ * @details
+ * Obsolete variant of gss_verify for V1 compatibility 
  * Check a MIC of the date
  *
  * @param minor_status
@@ -370,4 +357,4 @@ GSS_CALLCONV gss_verify(
     GLOBUS_I_GSI_GSSAPI_DEBUG_EXIT;
     return major_status;
 }
-/* @} */
+/* gss_verify() */
